import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:intl/intl.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_date_picker_bloc/analytics_date_picker_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/widgets/month_picker_widget.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/fetch_energy_management_data_helper.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class AnalyticsDateFilterButton extends StatefulWidget {
  const AnalyticsDateFilterButton({super.key});

  static final _color = ColorsManager.blackColor.withValues(alpha: 0.8);

  @override
  State<AnalyticsDateFilterButton> createState() =>
      _AnalyticsDateFilterButtonState();
}

class _AnalyticsDateFilterButtonState extends State<AnalyticsDateFilterButton> {
  late final AnalyticsDatePickerBloc _analyticsDatePickerBloc;
  @override
  void initState() {
    _analyticsDatePickerBloc = AnalyticsDatePickerBloc();
    super.initState();
  }

  @override
  void dispose() {
    _analyticsDatePickerBloc.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return BlocProvider.value(
      value: _analyticsDatePickerBloc,
      child: Builder(builder: (context) {
        final selectedDate = context.watch<AnalyticsDatePickerBloc>().state;
        return TextButton.icon(
          style: TextButton.styleFrom(
            foregroundColor: AnalyticsDateFilterButton._color,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(16),
              side: const BorderSide(
                color: ColorsManager.greyColor,
                width: 1,
              ),
            ),
            backgroundColor: ColorsManager.transparentColor,
            padding: const EdgeInsets.symmetric(
              horizontal: 32,
              vertical: 16,
            ),
          ),
          icon: SvgPicture.asset(
            Assets.blankCalendar,
            height: 20,
            width: 20,
            colorFilter:
                ColorFilter.mode(AnalyticsDateFilterButton._color, BlendMode.srcIn),
          ),
          label: Text(
            _formatDate(selectedDate),
            style: const TextStyle(
              fontWeight: FontWeight.w700,
            ),
          ),
          onPressed: () {
            showDialog(
              context: context,
              builder: (_) => MonthPickerWidget(
                selectedDate: selectedDate,
                onDateSelected: (value) {
                  _analyticsDatePickerBloc.add(
                    UpdateAnalyticsDatePickerEvent(value),
                  );
                  FetchEnergyManagementDataHelper.fetchEnergyManagementData(
                    context,
                    selectedDate: value,
                  );
                },
              ),
            );
          },
        );
      }),
    );
  }

  String _formatDate(DateTime? date) {
    final formatter = DateFormat('MMMM yyyy');
    final formattedDate = formatter.format(date ?? DateTime.now());
    return formattedDate;
  }
}
